<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Sg_Order_Approval_Woocommerce_Pro
 * @subpackage Sg_Order_Approval_Woocommerce_Pro/admin
 * @author     Sevengits <sevengits@gmail.com>
 */
class Sg_Order_Approval_Woocommerce_Pro_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Sg_Order_Approval_Woocommerce_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Sg_Order_Approval_Woocommerce_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/sg-order-approval-woocommerce-pro-admin.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Sg_Order_Approval_Woocommerce_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Sg_Order_Approval_Woocommerce_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/sg-order-approval-woocommerce-pro-admin.js', array('jquery'), $this->version, false);
	}
	/**
	 * add custom status
	 * @since    1.0.0
	 */
	function oawoo_register_my_new_order_statuse_wc_waiting()
	{

		register_post_status('wc-waiting', array(
			'label'                     => _x('Waiting for approval', 'Order status', 'dokan-order-approval'),
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => true,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop('Waiting approval <span class="count">(%s)</span>', 'Waiting<span class="count">(%s)</span>', 'dokan-order-approval')
		));
	}

	/**
	 * add custom status
	 * @since    1.0.0
	 
	 */

	function oawoo_wc_order_statuse_wc_waiting($order_statuses)
	{
		$order_statuses['wc-waiting'] = _x('Waiting for approval', 'Order status', 'dokan-order-approval');

		return $order_statuses;
	}
	/**
	 * @since 1.0.0  add action button in admin 
	 * @return actions
	 */
	function oawoo_add_custom_order_status_actions_button($actions, $order)
	{

		if ($order->has_status(array('waiting'))) {

			$actions['wc_approved'] = array(
				'url'       => wp_nonce_url(admin_url('admin-ajax.php?action=woocommerce_mark_order_status&status=pending&order_id=' . $order->get_id()), 'woocommerce-mark-order-status'),
				'name'      => __('Approve', 'dokan-order-approval'),
				'action'    => 'wc_approved',
			);
			// Set the action button
			$actions['wc_reject'] = array(
				'url'       => wp_nonce_url(admin_url('admin-ajax.php?action=woocommerce_mark_order_status&status=cancelled&order_id=' . $order->get_id()), 'woocommerce-mark-order-status'),
				'name'      => __('Reject', 'dokan-order-approval'),
				'action'    => 'wc_reject',
			);
		}

		return $actions;
	}
	/**
	 * 
	 * @since 1.0.0  add action button in admin 
	 
	 */


	function oawoo_add_custom_order_status_actions_button_css()
	{

		echo '<style>.wc-action-button-wc_approved::after { font-family: woocommerce !important; content: "\e015" !important; color:GREEN }</style>';
		echo '<style>.wc-action-button-wc_reject::after { font-family: woocommerce !important; content: "\e013" !important; color:RED}</style>';
	}
	/**
	 * @since 1.0.0  
	 * Add the gateway to WC Available Gateways
	 */

	function oawoo_wc_add_to_gateways($gateways)
	{

		$gateways[] = 'Woa_Gateway';
		return $gateways;
	}

	/**
	 *  @since 1.0.0  
	 * Adds plugin page links
	 */

	function oawoo_wc_gateway_plugin_links($links)
	{

		$plugin_links = array(
			'<a href="' . admin_url('admin.php?page=wc-settings&tab=advanced&section=sg_order_tab') . '">' . __('Settings', 'dokan-order-approval') . '</a>',


		);

		return array_merge($plugin_links, $links);
	}

	/**
	 *  @since 1.0.0  
	 * 
	 */
	function oawoo_wc_gateway_init()
	{

		require_once SGDA_PLUGIN_PATH . 'includes/class-sg-order-approval-woocommerce-pro-payment-gateway.php';
	}
	/**
	 *  @since 1.0.0  
	 * 
	 */

	function email_waiting_new_order_notifications($order_id, $order)
	{

		if ($order->get_parent_id() == '0') {

			WC()->mailer()->get_emails()['WC_Customer_Order_New']->trigger($order_id);
			WC()->mailer()->get_emails()['WC_Admin_Order_New']->trigger($order_id);
			WC()->mailer()->get_emails()['SG_Vendor_Order']->trigger( $order_id );
		} else {
			WC()->mailer()->get_emails()['SG_Vendor_Order']->trigger($order_id);
		}
	}

	/**
	 *  @since 1.0.0  
	 * 
	 */

	function oawoo_status_waiting_rejected_notification($order_id, $order)
	{

		WC()->mailer()->get_emails()['WC_Customer_Order_Rejected']->trigger($order_id);
	}


	/**
	 *  @since 1.0.0  
	 * 
	 */

	function oawoo_status_waiting_approved_notification($order_id, $order)
	{

		WC()->mailer()->get_emails()['WC_Customer_Order_Approved']->trigger($order_id);
	}

	/**
	 *	@since 1.0.0 
	 */
	public function sg_get_settings($settings, $current_section)
	{

		$custom_settings = array();

		if ('sg_order_tab' == $current_section) {
			$payment_link = admin_url()."admin.php?page=wc-settings&tab=checkout";
			$e_link = admin_url().'admin.php?page=wc-settings&tab=email';

			$custom_settings =  array(

				array(
					'name' => __('Dokan Order Approval', 'dokan-order-approval'),
					'type' => 'title',
					'desc' =>	sprintf( __( 'Free version dokan order approval plugin enabled for all orders.<p> Enable order approval at <a href="%s" target="_blank">payments</a> & customise  <a href="%s" target="_blank">emails</a>.</p> If you want to enable order approval for specific product please purchase  <a href="%s" target="_blank">premium version</a>.', 'dokan-order-approval' ),$payment_link,$e_link,'https://sevengits.com/plugin/dokan-order-approval?utm_source=dashboard&utm_medium=settings_page&utm_campaign=free-plugin'),
					'id'   => 'sg_tab_main_order'
				),
				
				array('type' => 'sectionend', 'id' => 'order_woo'),

			);

			return $custom_settings;
		} else {
			return $settings;
		}
	}
	/**
	 *	@since 1.0.0 
	 */

	public function sg_add_settings_tab($settings_tab)
	{
		$settings_tab['sg_order_tab'] = __('Dokan Order Approval');
		return $settings_tab;
	}
	/**
	 * @since 1.0.0 add checkbox in product general tab
	 */

	function sg_preorder_check_product_options()
	{

		echo '<div class="options_group">';

		woocommerce_wp_checkbox(array(
			'id'      => 'sg_product_enable',
			'value'   => get_post_meta(get_the_ID(), 'sg_product_enable', true),
			'label'   => 'Requires confirmation?',
			'desc_tip' => false,
			'description' => 'Check this box if the order requires admin approval/confirmation. Payment will not be taken during checkout.',
		));

		echo '</div>';
	}

	/** 
	 * @since 1.0.0  save field
	 */

	function sg_save_fields($id, $post)
	{
		if (isset($_POST['sg_product_enable'])) {
			$sg_product_enable = 'yes';
		} else {
			$sg_product_enable = 'no';
		}

		update_post_meta($id, 'sg_product_enable', $sg_product_enable);
	}

	function wc_make_processing_orders_editable($is_editable, $order)
	{


		if ($order->get_status() == 'waiting') {
			$is_editable = true;
		}

		return $is_editable;
	}
	/**
	 * @since 1.0.1
	 */
	function oawoo_plugin_row_meta( $links, $file ) {    
		if ( strpos( $file, 'dokan-order-approval.php' ) !== false ) {
			$new_links = array(
									'pro' => '<a href="https://sevengits.com/plugin/dokan-order-approval/?utm_source=dashboard&utm_medium=plugins-link&utm_campaign=free-plugin" target="_blank" class="order-pro-link">Buy Premium</a>',
									'docs' => '<a href="https://sevengits.com/plugin/dokan-order-approval/?utm_source=dashboard&utm_medium=plugins-link&utm_campaign=free-plugin" target="_blank">Docs</a>',
									'support' => '<a href="https://wordpress.org/support/plugin/dokan-order-approval/?utm_source=dashboard&utm_medium=plugins-link&utm_campaign=free-plugin" target="_blank">Free Support</a>'
					);
			
			$links = array_merge( $links, $new_links );
		}
		
		return $links;
	}
	/**
	 * @since  1.0.1
	 */
	function sg_custom_admin_css(){
		echo '<style>
		a.order-pro-link {
			color: #e75152 !important;
			font-weight: bold !important;
		}
  		</style>';
	}

	function sgda_custom_update_order_meta( $order_id ) {
		if ( ! $order_id )
        return;
		// Allow code execution only once 
		if( ! get_post_meta( $order_id, '_thankyou_action_done', true ) ) {
			if(get_post_meta( $order_id, '_payment_method', true )=='woa_gateway'){
				$sgda_total_orders=get_option( 'sgda_total_orders', 0 );
				update_option( 'sgda_total_orders',$sgda_total_orders + 1);
			}
		}	
		
   }

}
